==> kara-uc-1.2.26.tgz: package/src/kara-uc/components/UCMedal/showView/index.js <==
import React from 'react';
import style from './style.scss'
import moment from 'moment'
import tost,{errorTost} from "kara-module-tost";
import {ForwardColl} from 'karaui'
import 'karaui/lib/index.css'
export default class ShowViews extends React.Component{
    state={
        count:0,
        details: {},
        forwardShow:false,
        shareList:{}
    }
    componentDidMount(){
        const {ConfigStore,list} =this.props
        ConfigStore.config.httpAgent.get(`/medal/won/account/count/${list.medalId}`).then(
            res => {
                if(res && res.resultCode && res.resultCode === '000000') {
                    this.setState({count:res.count})
                }
                else {
                    tost({type:'error',msg:'获取信息失败',time:4})
                }

            }
        )
        ConfigStore.config.httpAgent.post('/medal/info/new',{
            medalId: list.medalId,
            year: null
        }).then(
            res => {
                if(res && res.resultCode && res.resultCode === '000000') {
                    this.setState({details:res.result})
                }
                else {
                    tost({type:'error',msg:'获取详细信息失败',time:4})
                }

            }
        )
        this.setState({
            shareList:{
                url:list.shareUrl,  // 详情页url
                thumbUrl:list.medalIcon,  //  缩略图
                description:list.medalDesc,
                title:list.medalName
            }
        })
    }
    closeModal=()=>{
        this.setState({forwardShow:false})
    }
    render(){
        console.log(this.props)
        const {list,callback,Modal,ConfigStore:{config:{httpAgent}}} = this.props
        const {forwardShow,shareList, details} = this.state;
        const time = details && details.createTime ? moment(details.createTime).format("YYYY.MM.DD") : moment(list.wonTime).format("YYYY.MM.DD")
        return(
            <div className={style["app"]}>
                <div className={style["view-back"]} onClick={()=>callback(false)}></div>
                <div className={style["view-content"]}>
                    <div className={style["view-btns"]}></div>
                    <div className={style["view-icon"]}>
                        <img src={list.medalIcon} alt={"img"}/>
                    </div>
                    <div className={style["view-text"]}>
                        <div className={style['view-tiems']}>{time}获得</div>
                        <div className={style["view-medal"]}>{list.medalName}</div>
                        <div className={style["view-context"]}>{list.medalDesc}</div>
                        <div className={style["view-num"]}>已有<em>{this.state.count}</em>人获得</div>
                        <div className={style['view-btn']} onClick={()=>this.setState({forwardShow:true})}>分享</div>
                    </div>
                </div>
                <Modal show={forwardShow} onMask={this.closeModal}>
                    <ForwardColl httpAgent={httpAgent} modalHidden={this.closeModal} shareParams={shareList} type='quan'/>
                </Modal>
            </div>
        )
    }
}

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCMedal/showView/index.js <==
import React from 'react';
import style from './style.scss'
import moment from 'moment'
import tost,{errorTost} from "kara-module-tost";
import {ForwardColl} from 'karaui'
import 'karaui/lib/index.css'
export default class ShowViews extends React.Component{
    state={
        count:0,
        details: {},
        forwardShow:false,
        shareList:{}
    }
    componentDidMount(){
        const {ConfigStore,list,year=new Date().getFullYear()} =this.props
        ConfigStore.config.httpAgent.get(`/medal/won/account/count/${list.medalId}`).then(
            res => {
                if(res && res.resultCode && res.resultCode === '000000') {
                    this.setState({count:res.count})
                }
                else {
                    tost({type:'error',msg:'获取信息失败',time:4})
                }

            }
        )
        ConfigStore.config.httpAgent.post('/medal/info/new',{
            medalId: list.medalId,
            year: year?year:null
        }).then(
            res => {
                if(res && res.resultCode && res.resultCode === '000000') {
                    this.setState({details:res.result})
                }
                else {
                    tost({type:'error',msg:'获取详细信息失败',time:4})
                }

            }
        )
        this.setState({
            shareList:{
                url:list.shareUrl,  // 详情页url
                thumbUrl:list.medalIcon,  //  缩略图
                description:list.medalDesc,
                title:list.medalName
            }
        })
    }
    closeModal=()=>{
        this.setState({forwardShow:false})
    }
    render(){
        const {list,callback,Modal,ConfigStore:{config:{httpAgent}}} = this.props
        const {forwardShow,shareList, details} = this.state;
        const time = details && details.createTime ? moment(details.createTime).format("YYYY.MM.DD") : moment(list.wonTime).format("YYYY.MM.DD")
        return(
            <div className={style["app"]}>
                <div className={style["view-back"]} onClick={()=>callback(false)}></div>
                <div className={style["view-content"]}>
                    <div className={style["view-btns"]}></div>
                    <div className={style["view-icon"]}>
                        <img src={list.medalIcon} alt={"img"}/>
                    </div>
                    <div className={style["view-text"]}>
                        <div className={style['view-tiems']}>{time}获得</div>
                        <div className={style["view-medal"]}>{list.medalName}</div>
                        <div className={style["view-context"]}>{list.medalDesc}</div>
                        <div className={style["view-num"]}>已有<em>{this.state.count}</em>人获得</div>
                        <div className={style['view-btn']} onClick={()=>this.setState({forwardShow:true})}>分享</div>
                    </div>
                </div>
                <Modal show={forwardShow} onMask={this.closeModal}>
                    <ForwardColl httpAgent={httpAgent} modalHidden={this.closeModal} shareParams={shareList} type='quan'/>
                </Modal>
            </div>
        )
    }
}
